"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
const getFlights_1 = require("./getFlights");
const pageRegex = /page=(\d*).+rel="(\w*)"/;
class Schiphol {
    constructor(applicationId, applicationKey) {
        this.applicationId = applicationId;
        this.applicationKey = applicationKey;
        // add functions
        this.getFlights = getFlights_1.default;
    }
    fetch(url, params = {}) {
        params.app_id = this.applicationId;
        params.app_key = this.applicationKey;
        let page = 0;
        if (params.page) {
            page = params.page;
        }
        let paramString = '';
        for (const param in params) {
            if (param !== 'getAllPages' && param !== 'page') {
                paramString += `&${param}=${params[param]}`;
            }
        }
        // replace the first symbol with an ?
        paramString = '?' + paramString.substring(1);
        return this.getResponse(url, params.getAllPages === true, paramString, page);
    }
    getLocationInfoFromLinkHeader(linkHeader) {
        const locationInfo = {};
        if (!linkHeader) {
            return locationInfo;
        }
        let matches;
        linkHeader.split(',').forEach(linkPart => {
            if ((matches = pageRegex.exec(linkPart)) !== null) {
                const page = parseInt(matches[1], 10);
                const type = matches[2];
                locationInfo[type] = page;
            }
        });
        return locationInfo;
    }
    parseResult(res) {
        return res.json().then(response => {
            delete response.schemaVersion;
            return response[Object.keys(response)[0]];
        }).catch(err => {
            throw new Error('Unable to parse response json.');
        });
    }
    getResponse(url, getAllPages, paramString, page) {
        return node_fetch_1.default(url + paramString + '&page=' + page, {
            headers: { ResourceVersion: 'v3' },
        })
            .then(res => {
            if (!res.ok) {
                throw new Error(`Unexpected response status "${res.status}: ${res.statusText}"`);
            }
            const linkHeader = res.headers.get('link');
            const locationInfo = this.getLocationInfoFromLinkHeader(linkHeader);
            if (getAllPages && locationInfo.next) {
                // we need to get the next page!
                return Promise.all([
                    this.parseResult(res),
                    this.getResponse(url, getAllPages, paramString, locationInfo.next),
                ]).then(result => ({
                    response: result[0].concat(result[1].response),
                }));
            }
            else {
                return this.parseResult(res).then(response => ({
                    locationInfo,
                    response,
                }));
            }
        });
    }
}
exports.default = Schiphol;
